import type { CreateClientOptions, RequestOptions } from '@algolia/client-common';
import type { BaseResponse } from '../model/baseResponse';
import type { DelProps, DeleteConfigProps, GetProps, GetConfigProps, GetConfigStatusProps, GetLogFileProps, PostProps, PutProps, UpdateConfigProps } from '../model/clientMethodProps';
import type { GetConfigStatus200Response } from '../model/getConfigStatus200Response';
import type { GetLogFile200Response } from '../model/getLogFile200Response';
import type { QuerySuggestionsConfigurationResponse } from '../model/querySuggestionsConfigurationResponse';
import type { QuerySuggestionsConfigurationWithIndex } from '../model/querySuggestionsConfigurationWithIndex';
export declare const apiClientVersion = "5.0.0-alpha.85";
export declare const REGIONS: readonly ["eu", "us"];
export type Region = (typeof REGIONS)[number];
export declare function createQuerySuggestionsClient({ appId: appIdOption, apiKey: apiKeyOption, authMode, algoliaAgents, region: regionOption, ...options }: CreateClientOptions & {
    region: Region;
}): {
    transporter: import("@algolia/client-common").Transporter;
    /**
     * The `appId` currently in use.
     */
    appId: string;
    /**
     * Clears the cache of the transporter for the `requestsCache` and `responsesCache` properties.
     */
    clearCache(): Promise<void>;
    /**
     * Get the value of the `algoliaAgent`, used by our libraries internally and telemetry system.
     */
    readonly _ua: string;
    /**
     * Adds a `segment` to the `x-algolia-agent` sent with every requests.
     *
     * @param segment - The algolia agent (user-agent) segment to add.
     * @param version - The version of the agent.
     */
    addAlgoliaAgent(segment: string, version?: string): void;
    /**
     * Create a new Query Suggestions configuration.  You can have up to 100 configurations per Algolia application.
     *
     * @summary Create a configuration.
     * @param querySuggestionsConfigurationWithIndex - The querySuggestionsConfigurationWithIndex object.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    createConfig(querySuggestionsConfigurationWithIndex: QuerySuggestionsConfigurationWithIndex, requestOptions?: RequestOptions): Promise<BaseResponse>;
    /**
     * This method allow you to send requests to the Algolia REST API.
     *
     * @summary Send requests to the Algolia REST API.
     * @param del - The del object.
     * @param del.path - Path of the endpoint, anything after \"/1\" must be specified.
     * @param del.parameters - Query parameters to apply to the current query.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    del({ path, parameters }: DelProps, requestOptions?: RequestOptions): Promise<Record<string, any>>;
    /**
     * Delete a Query Suggestions configuration.  Deleting only removes the configuration and stops updates to the Query Suggestions index. The Query Suggestions index itself is not deleted.
     *
     * @summary Delete a configuration.
     * @param deleteConfig - The deleteConfig object.
     * @param deleteConfig.indexName - Query Suggestions index name.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    deleteConfig({ indexName }: DeleteConfigProps, requestOptions?: RequestOptions): Promise<BaseResponse>;
    /**
     * This method allow you to send requests to the Algolia REST API.
     *
     * @summary Send requests to the Algolia REST API.
     * @param get - The get object.
     * @param get.path - Path of the endpoint, anything after \"/1\" must be specified.
     * @param get.parameters - Query parameters to apply to the current query.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    get({ path, parameters }: GetProps, requestOptions?: RequestOptions): Promise<Record<string, any>>;
    /**
     * List all Query Suggestions configurations of your Algolia application.
     *
     * @summary List configurations.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    getAllConfigs(requestOptions?: RequestOptions): Promise<QuerySuggestionsConfigurationResponse[]>;
    /**
     * Get a single Query Suggestions configuration.
     *
     * @summary Get a configuration.
     * @param getConfig - The getConfig object.
     * @param getConfig.indexName - Query Suggestions index name.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    getConfig({ indexName }: GetConfigProps, requestOptions?: RequestOptions): Promise<QuerySuggestionsConfigurationResponse>;
    /**
     * Report the status of a Query Suggestions index.
     *
     * @summary Get configuration status.
     * @param getConfigStatus - The getConfigStatus object.
     * @param getConfigStatus.indexName - Query Suggestions index name.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    getConfigStatus({ indexName }: GetConfigStatusProps, requestOptions?: RequestOptions): Promise<GetConfigStatus200Response>;
    /**
     * Get the logs for a single Query Suggestions index.
     *
     * @summary Get logs.
     * @param getLogFile - The getLogFile object.
     * @param getLogFile.indexName - Query Suggestions index name.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    getLogFile({ indexName }: GetLogFileProps, requestOptions?: RequestOptions): Promise<GetLogFile200Response>;
    /**
     * This method allow you to send requests to the Algolia REST API.
     *
     * @summary Send requests to the Algolia REST API.
     * @param post - The post object.
     * @param post.path - Path of the endpoint, anything after \"/1\" must be specified.
     * @param post.parameters - Query parameters to apply to the current query.
     * @param post.body - Parameters to send with the custom request.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    post({ path, parameters, body }: PostProps, requestOptions?: RequestOptions): Promise<Record<string, any>>;
    /**
     * This method allow you to send requests to the Algolia REST API.
     *
     * @summary Send requests to the Algolia REST API.
     * @param put - The put object.
     * @param put.path - Path of the endpoint, anything after \"/1\" must be specified.
     * @param put.parameters - Query parameters to apply to the current query.
     * @param put.body - Parameters to send with the custom request.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    put({ path, parameters, body }: PutProps, requestOptions?: RequestOptions): Promise<Record<string, any>>;
    /**
     * Update a QuerySuggestions configuration.
     *
     * @summary Update a configuration.
     * @param updateConfig - The updateConfig object.
     * @param updateConfig.indexName - Query Suggestions index name.
     * @param updateConfig.querySuggestionsConfiguration - The querySuggestionsConfiguration object.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    updateConfig({ indexName, querySuggestionsConfiguration }: UpdateConfigProps, requestOptions?: RequestOptions): Promise<BaseResponse>;
};
/**
 * The client type.
 */
export type QuerySuggestionsClient = ReturnType<typeof createQuerySuggestionsClient>;
//# sourceMappingURL=querySuggestionsClient.d.ts.map